Documentation
¶
Overview ¶
Teogw client connection and processing package
Index ¶
- type Teogw
- type TeogwData
- func (gw TeogwData) GetAddress() string
- func (gw TeogwData) GetCommand() string
- func (gw TeogwData) GetData() []byte
- func (gw TeogwData) GetID() uint32
- func (gw *TeogwData) MarshalBinary() (out []byte, err error)
- func (gw TeogwData) MarshalJson(gwData teowebrtc_server.WebRTCData, command string, inData []byte, inErr error) ([]byte, error)
- func (gw *TeogwData) SetCommand(command string)
- func (gw *TeogwData) SetData(data []byte)
- func (gw *TeogwData) SetError(err error)
- func (gw *TeogwData) SetID(id uint32)
- func (gw *TeogwData) UnmarshalBinary(data []byte) (err error)
- func (gw TeogwData) UnmarshalJson(data []byte) (teowebrtc_server.WebRTCData, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Teogw ¶
Teogw structure and methods receiver
type TeogwData ¶
type TeogwData struct {
ID uint32 `json:"id"`
Address string `json:"address"`
Command string `json:"command"`
Data []byte `json:"data"`
Err string `json:"err"`
}
Teogw packet data
func (*TeogwData) MarshalBinary ¶
MarshalBinary marshal Teogw binary packet
func (TeogwData) MarshalJson ¶ added in v0.6.4
func (gw TeogwData) MarshalJson( gwData teowebrtc_server.WebRTCData, command string, inData []byte, inErr error) ([]byte, error)
Marshal TeogwData to Json
func (*TeogwData) SetCommand ¶ added in v0.6.4
Set data
func (*TeogwData) UnmarshalBinary ¶
UnmarshalBinary unmarshal Teogw binary packet
func (TeogwData) UnmarshalJson ¶ added in v0.6.4
func (gw TeogwData) UnmarshalJson(data []byte) (teowebrtc_server.WebRTCData, error)
Unmarshal Json and return TeogwData
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
teogw
command
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru.
|
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru. |
|
teogwcli
command
Teogw client sample apllication
|
Teogw client sample apllication |
Click to show internal directories.
Click to hide internal directories.