Documentation
¶
Overview ¶
Teogw client connection and processing package
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Teogw ¶
Teogw structure and methods receiver
type TeogwData ¶
type TeogwData struct {
ID uint32 `json:"id"`
Address string `json:"address"`
Command string `json:"command"`
Data []byte `json:"data"`
Err string `json:"err"`
}
Teogw packet data
func (*TeogwData) MarshalBinary ¶
MarshalBinary marshal Teogw binary packet
func (*TeogwData) UnmarshalBinary ¶
UnmarshalBinary unmarshal Teogw binary packet
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
teogw
command
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru.
|
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru. |
|
teogwcli
command
Teogw client sample apllication
|
Teogw client sample apllication |
Click to show internal directories.
Click to hide internal directories.