Documentation
¶
Overview ¶
Teogw client connection and processing package
Index ¶
- type Teogw
- type TeogwData
- func (gw *TeogwData) Address() string
- func (gw *TeogwData) Command() string
- func (gw *TeogwData) Data() []byte
- func (gw *TeogwData) MarshalBinary() (out []byte, err error)
- func (gw *TeogwData) SetData(data []byte)
- func (gw *TeogwData) SetError(err error)
- func (gw *TeogwData) SetID(id uint32)
- func (gw *TeogwData) UnmarshalBinary(data []byte) (err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Teogw ¶
Teogw structure and methods receiver
type TeogwData ¶
type TeogwData struct {
// contains filtered or unexported fields
}
Teogw packet data
func (*TeogwData) MarshalBinary ¶
MarshalBinary marshal Teogw binary packet
func (*TeogwData) UnmarshalBinary ¶
UnmarshalBinary unmarshal Teogw binary packet
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
teogw
command
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru.
|
Teogw teonet application get request by tru, execute it in teonet and send responce back by tru. |
|
teogwcli
command
Teogw client sample apllication
|
Teogw client sample apllication |
Click to show internal directories.
Click to hide internal directories.